@@ -42,7 +42,13 @@ class PrintRequest(object):
             self.format=None   
             
     def deserializeSingle(self,value):
-        """ deserialize a single value """
+        """ deserialize a single value 
+        Args:
+            value(object): the value to be deserialized according to the typeid
+            
+        Returns:
+            the deserialized value
+        """
         # FIXME complete list of types according to
         # https://www.semantic-mediawiki.org/wiki/Help:API:ask  
         # Page https://www.semantic-mediawiki.org/wiki/Help:API:ask/Page    
@@ -85,8 +91,14 @@ class PrintRequest(object):
             valueList=[]
             for valueItem in value:
                 valueList.append(self.deserializeSingle(valueItem))
-            if len(valueList)==1:
+            # handle lists
+            # empty lists => None
+            if len(valueList)==0:
+                value=None    
+            # lists with one value -> return the item (this unfortunately removes the list property of the value)   
+            elif len(valueList)==1:
                 value=valueList[0]
+            # only if there is a "real" list return it    
             else:        
                 value=valueList  
         else:
